@@ -1,7 +1,12 @@
 from .utils import appdir
 import g4f
+from importlib import metadata
+
+try:
+    __version__ = metadata.version("python-tgpt")
+except metadata.PackageNotFoundError:
+    __version__ = "0.0.0"
 
-__version__ = "0.4.8"
 __author__ = "Smartwa"
 __repo__ = "https://github.com/Simatwa/python-tgpt"
 
@@ -10,13 +15,14 @@ tgpt_providers = [
     "openai",
     "opengpt",
     "koboldai",
-    "bard",
+    "gemini",
     "phind",
     "llama2",
     "blackboxai",
     "gpt4all",
     "webchatgpt",
     "g4fauto",
+    "poe",
 ]
 
 gpt4free_providers = [
